'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var fs = require('fs-extra');
var yaml = require('js-yaml');
var zod = require('zod');
var globby = require('globby');
var k8sApply = require('k8s-apply');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);

const templateAndValidateKubernetesAction = (options) => {
  const fetchTemplate = pluginScaffolderBackend.createFetchTemplateAction(options);
  return pluginScaffolderBackend.createTemplateAction({
    id: "template:validate:kubernetes",
    description: "Templates Kubernetes manifests, validates them, and outputs to a defined path.",
    schema: {
      input: zod.z.object({
        url: zod.z.string().describe("URL of the manifest files to template"),
        values: zod.z.record(zod.z.any()).describe("Values to pass to the templating engine"),
        outputPath: zod.z.string().describe("Output path for the templated files")
      })
    },
    async handler(ctx) {
      await fetchTemplate.handler({
        ...ctx,
        input: {
          ...ctx.input
        }
      });
      const { outputPath } = ctx.input;
      const templatedDir = ctx.workspacePath;
      const files = await globby.globby("**/*.yaml", { cwd: templatedDir });
      for (const file of files) {
        const filePath = `${templatedDir}/${file}`;
        const content = await fs__default["default"].readFile(filePath, "utf8");
        try {
          yaml__namespace.load(content);
        } catch (error) {
          const yamlError = error instanceof Error ? error : new Error(`Unknown error: ${error}`);
          ctx.logger.error(
            `YAML validation error in ${file}: ${yamlError.message}`
          );
          throw yamlError;
        }
        const outputPathResolved = `${outputPath}/${file}`;
        await fs__default["default"].move(filePath, outputPathResolved, { overwrite: true });
      }
      ctx.logger.info(
        `Kubernetes manifests templated, validated, and written to ${outputPath}`
      );
    }
  });
};

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    description: "Deploys Kubernetes manifests.",
    schema: {
      input: zod.z.object({
        manifest: zod.z.string().describe("The Kubernetes manifest path"),
        authToken: zod.z.string().describe("Authentication token to access the Kubernetes cluster"),
        clusterUrl: zod.z.string().describe("URL of the Kubernetes cluster")
      })
    },
    async handler(ctx) {
      const { manifest, authToken, clusterUrl } = ctx.input;
      try {
        let manifestYaml = "";
        try {
          manifestYaml = await fs__default["default"].promises.readFile(ctx.input.manifest, {
            encoding: "utf-8"
          });
        } catch (fileError) {
          ctx.logger.error(`Error reading file: ${manifest}`, fileError);
          throw fileError;
        }
        let manifestObject;
        try {
          manifestObject = yaml__namespace.load(manifestYaml);
        } catch (yamlError) {
          ctx.logger.error("Error parsing YAML content", yamlError);
          throw yamlError;
        }
        const response = await k8sApply.applyObject(manifestObject, {
          server: clusterUrl,
          token: authToken
        });
        ctx.logger.info(`Deployment response: ${JSON.stringify(response)}`);
      } catch (error) {
        ctx.logger.error(`Deployment failed: ${error}`);
        throw error;
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
exports.templateAndValidateKubernetesAction = templateAndValidateKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
